<?php

declare(strict_types=1);

namespace App\Controller;

use App\JsonRpc\LinkServiceInterface;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Context\Context;

use Hyperf\Logger;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;

/**
 * Class LinkController
 * @package App\Controller
 */
//#[AutoController]
class LinkController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;
    /**
     * @var LinkServiceInterface
     */
    #[Inject]
    private $linkServiceClient;

    /**
     * 友情链接列表
     * @return array
     */
    public function getLinkList()
    {
        $requireData = $this->request->all();
        $result = $this->linkServiceClient->getLinkList($requireData);
        if($result['data']){
            $statusList = ['1'=>"通过",'2'=>"待审"];
            foreach ($result['data']['rows'] as $k=>$v) {
                $result['data']['rows'][$k]['status_name'] =$statusList[$v['status']];
            }
        }
        return $result?Result::success($result['data']):Result::error($result['message']);
    }

    /**
     * 创建友情链接
     * @return array
     */
    public function createLink()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title' => 'required',
            ],
            [
                'title.required' => '名称不能为空',
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->linkServiceClient->createLink($requireData);
        return $result?Result::success($result['data']):Result::error($result['message']);
    }

    /**
     * 更新友情链接
     * @return array
     */
    public function updateLink()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'title' => 'required',
                'url' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'title.required' => '名称不能为空',
                'url.required' => 'url不能为空',
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData = $this->request->all();
        $result = $this->linkServiceClient->updateLink($requireData);
        return $result?Result::success($result['data']):Result::error($result['message']);
    }

    /**
     * 删除友情链接
     * @return array
     */
    public function delLink()
    {
        $requireData = $this->request->all();
        $result = $this->linkServiceClient->delLink($requireData);
        return $result?Result::success($result['data']):Result::error($result['message']);
    }


}